<?php
/*
  Plugin Name: Pin Button Attraction for Wordpress
  Version: 5.4
  Description: Easy Image Pinning for Wordpress
  Author: GoFish
 */
$plugin_path = WP_PLUGIN_DIR . '/' . str_replace(basename(__FILE__), "", plugin_basename(__FILE__)); // determine plugin DIR path
define('E_DIR', $plugin_path);

$plugin_url = plugins_url(basename(dirname(__FILE__))); // determine plugin ABS path
define('E_URL', $plugin_url); // define plugin ABS path
// INCLUDE HELPER FUNCTIONS
include_once(E_DIR . 'libs/helper.php');

// INCLUDE PINME FUNCTIONS
include_once(E_DIR . 'libs/pin-functions.php');

// LOAD BACKEND STYLES & SCRIPTS
include_once(E_DIR . 'libs/load-scripts.php');

// INCLUDE PINTEREST FUNCTION
include_once(E_DIR . 'libs/pinterest.php');

// INCLUDE PINTEREST OPTIONS ON POSTS & PAGES
include_once(E_DIR . 'libs/page-options.php');

// ADD PINTEREST GENERAL OPTIONS PAGE
include_once(E_DIR . 'libs/general-options.php');

register_activation_hook(__FILE__, 'easy_pinning_activate'); // on activation make unpinned images pinned recursively

function easy_pinning_activate() {
    $args = array('post_type' => 'attachment', 'posts_per_page' => -1, 'post_status' => null, 'post_parent' => null);
    $attachments = get_posts($args);
    if ($attachments) {
        foreach ($attachments as $post) {
            setup_postdata($post);
            $pinned = get_post_meta($post->ID, 'pinterest', true);
            if (!$pinned || empty($pinned))
                add_post_meta($post->ID, 'pinterest', 1);
        }
    }
}

// ADD SUPPORT FOR post-thumbnail IF NOT EXISTANT
add_action('after_setup_theme', 'easy_pinning_thumbnail_support');

function easy_pinning_thumbnail_support() {
    if (!current_theme_supports('post-thumbnails'))
        add_theme_support('post-thumbnails');
}

// ADD PIN WRAPPER FOR DOM DETECTION
add_filter('post_thumbnail_html', 'pin_featured_image', 10, 3);

function pin_featured_image($html, $post_id, $post_image_id) {
    $pinned = get_post_meta($post_image_id, 'pinterest', true);

    if (!ep_show_on_homepage())
        return $html; // check if homepage display option is on / off

    $display_featured = get_query_var('ep_display_featured');
    if ($pinned != 1 || !$display_featured)
        return $html; // if pin status not set, do nothing

    $wrapper_class = 'pin-holder pin-featured';
    $css_position = get_query_var('ep_pin_position');
    $attachment = get_post($post_image_id);
    $alt = get_post_meta($post_image_id, '_wp_attachment_image_alt', true);

    $args = array(
        'url' => get_permalink($post_id), // get url of post where attachment resides
        'media' => wp_get_attachment_url($post_image_id),
        'description' => $alt,
        'id' => $post_image_id,
        'layout' => get_query_var('ep_pin_layout'),
        'display_username' => false, // no follow me button
        'username' => false
    );

    $button = easy_pinning_string($args); // trigger pin button display
    $html = pin_html($post_image_id, $wrapper_class, $css_position, $html, $button); // return featured image HTML
    return $html;
}

// FILTER THE CONTENT FOR IMAGES
add_filter('the_content', 'easy_pinning_filter_content', 9999);

function easy_pinning_filter_content($content) {
    global $post;
    /*
      /* Checks if display images globally can be turn on / off
     */
    $switch = get_query_var('ep_functional'); // found in libs/general-options.php
    if ($switch) {
        if (!ep_show_on_homepage())
            return $content;

        $display = get_post_meta($post->ID, 'pinterest_display', true);
        if ($display == 2)
            return $content; // pinterest button is blocked
    } else
        return $content;

    if ($post->post_type == 'attachment') {
//		$pinned = get_post_meta( $post->ID , 'pinterest', true );
//		if ($pinned == 1) {
//			$button = easy_pinning_string($post->ID);
//			$wrapper = '<div id="pin-wrapper-'.$post->ID.'">'.$button.'</div>';
//			$content = $content.$wrapper;
//		}

        return $content;
    }

    if (empty($content))
        return $content;

    // INCLUDE DOM PARSING LIBRARY
    include_once(E_DIR . 'libs/simple-html-dom.php');
    $html = str_get_html($content); // parse the html
    
    $adsense_noise = $html->search_noise('google_ad_client', false);
    if ($adsense_noise): 
        foreach ($adsense_noise as $noise) {
            $html->noise[$noise['key']] = DEFAULT_BR_TEXT.$html->noise[$noise['key']].DEFAULT_BR_TEXT;
        }
    endif;

    $css_position = get_query_var('ep_pin_position');
    foreach ($html->find('img') as $element):
        $relme = false;
        if (ep_is_pinme($element)):
            $relme = true;
            $rel_args = array(
                'url' => get_permalink($post->ID),
                'media' => (isset($element->src)) ? $element->src : '',
                'description' => ''
            );

            $class = 'ep-relme-class' . (isset($element->attr['class']) ? ' ' . $element->attr['class'] : '');
            $wrap = $element->parent();
        else:
            $wrap = (ep_has_anchor($element)) ? $element->parent() : $element;
            if (!isset($element->attr['class']) || empty($element->attr['class']))
                continue;

            $class = $element->attr['class'];
            preg_match_all("/wp-image-([\d]+)/", $class, $id_arr);
        endif;

        if (isset($id_arr[1][0]) || $relme) {
            $media_id = ($relme) ? uniqid() : $id_arr[1][0];
            $pinned = ($relme) ? 1 : get_post_meta($media_id, 'pinterest', true);
            if ($pinned == 1) {

                if (!$relme):
                    $attachment_src = wp_get_attachment_image_src($media_id, 'full');
                    $attachment = get_post($media_id);
                    $alt = get_post_meta($media_id, '_wp_attachment_image_alt', true);
                endif;

                $args = array(
                    'url' => ($relme) ? $rel_args['url'] : get_permalink($attachment->post_parent), /* get url of post where attachment resides */
                    //'url' => get_attachment_link($media_id), /* get url of single attachment page */
                    'media' => ($relme) ? $rel_args['media'] : $attachment_src[0],
                    'description' => ($relme) ? $rel_args['description'] : $alt,
                    'id' => $media_id,
                    'layout' => get_query_var('ep_pin_layout'),
                    'display_username' => get_query_var('ep_display_username'),
                    'username' => get_query_var('ep_username')
                );

                $button = easy_pinning_string($args);

                $wrapper_class = 'pin-holder';
                if (strpos($class, 'alignleft') !== false)
                    $wrapper_class .= ' alignleft';
                elseif (strpos($class, 'alignright') !== false)
                    $wrapper_class .= ' alignright';
                elseif (strpos($class, 'aligncenter') !== false)
                    $wrapper_class .= ' aligncenter';
                elseif (strpos($class, 'alignnone') !== false)
                    $wrapper_class .= ' alignnone';

                $wrapper = pin_html($media_id, $wrapper_class, $css_position, $wrap, $button);
                $wrap->outertext = $wrapper;
                //$content = str_replace($output, $wrapper, $content);
            }
        }
    endforeach;

    //$html->clear(); 
    //unset($html);

    return $html;
}

/**
 * Generate Pin Button HTML
 * 
 * @param integer $media_id
 * @param string $wrapper_class
 * @param string $css_position
 * @param string $html
 * @param string $button
 * @return string 
 */
function pin_html($media_id, $wrapper_class, $css_position, $html, $button) {
    $wrapper = '<span id="pin-wrapper-' . $media_id . '" class="' . $wrapper_class . '">
					<span class="pin-wrapper ' . $css_position . '">';

    $display_mouseover = get_query_var('ep_display_mouseover');
    if ($display_mouseover == 'show-mouseover'):
        $wrapper .= '<span class="pin-mouseover"></span>';
    endif;

    $wrapper .= '<span class="pin-image-wrapper">' . $html . '</span>
						 <span class="pin-bundle-wrapper">' . $button . '</span>
					 </span>
					 <span class="pin-clear"></span>
				</span>';

    $wrapper = str_replace('\n', '', $wrapper);
    $wrapper = str_replace('\r', '', $wrapper);

    return $wrapper;
}

/**
 * Function to lookup pinterest field.
 *
 * returns an html string with button position or nothing.
 * */
function easy_pinning_string($args = '') {
    if (empty($args))
        return false;
    $button = '';
    $pin = new Pinterest;
    $button = $pin->add_pin_image($args);
    //$button .= '<span class="pin-clear"></span>';
    $button .= $pin->add_pin_button($args['display_username'], $args['username']);

    return $button;
}

/**
 * Adding our custom fields to the $form_fields array 
 * 
 * @param array $form_fields 
 * @param object $post 
 * @return array 
 */
function easy_pinning_attachment_fields_to_edit($form_fields, $post) {
    $pinterest = get_post_meta($post->ID, 'pinterest', true);
    if (!$pinterest)
        update_post_meta($post->ID, 'pinterest', 1);
    
    $pinterest = (!$pinterest && ep_image_switch()) ? 1 : $pinterest;

    $check1 = ($pinterest == 1) ? "checked = 'checked'" : "";
    $check2 = ($pinterest == 2 || !$pinterest) ? "checked = 'checked'" : "";

    $form_fields["pinterest"]["label"] = __("Include Pin Button on this image?");
    $form_fields["pinterest"]["input"] = "html";
    $form_fields["pinterest"]["html"] = "<label for='attachments1[{$post->ID}][pinterest]'>" . __('Yes') . "</label><input type='radio' value='1' {$check1} name='attachments[{$post->ID}][pinterest]' id='attachments1[{$post->ID}][pinterest]' />
										<label for='attachments2[{$post->ID}][pinterest]'>" . __('No') . "</label><input type='radio' value='2' {$check2} name='attachments[{$post->ID}][pinterest]' id='attachments2[{$post->ID}][pinterest]' />";
    $form_fields["pinterest"]["helps"] = __("Pin the image or not");

    return $form_fields;
}

// attach our function to the correct hook  
add_filter("attachment_fields_to_edit", "easy_pinning_attachment_fields_to_edit", 11, 2);

/**
 * @param array $post 
 * @param array $attachment 
 * @return array 
 */
function easy_pinning_attachment_fields_to_save($post, $attachment) {
    if (isset($attachment['pinterest'])) {
        if (trim($attachment['pinterest']) == '' || empty($attachment['pinterest'])) {
            // adding our custom error  
            $post['errors']['pinterest']['errors'][] = __('Fields must have a value.');
        } else {
            update_post_meta($post['ID'], 'pinterest', $attachment['pinterest']);
        }
    }
    return $post;
}

// attach our function to the correct hook  
add_filter('attachment_fields_to_save', 'easy_pinning_attachment_fields_to_save', 10, 2);


// FrontEnd load pinterest js & css on pages and posts
add_action('wp_enqueue_scripts', array('Pinterest', 'pinterest_frontend_css_js'), 10, 2);

// FrontEnd assign comon values to WP_QUERY global object
add_action('wp', 'pin_query_vars');

function pin_query_vars() {
    global $wp_query;

    $switch = ep_functional();
    $wp_query->set('ep_functional', $switch);

    if ($switch):
        $layout = ep_pin_layout();
        $display_username = ep_display_username();
        $username = ep_username();
        $display_mouseover = ep_display_mouseover();
        $display_homepage = ep_homepage_pin();
        $display_featured = ep_featured_pin();
        $pin_position = ep_pin_position();

        $wp_query->set('ep_pin_layout', $layout);
        $wp_query->set('ep_display_username', $display_username);
        $wp_query->set('ep_username', $username);
        $wp_query->set('ep_display_mouseover', $display_mouseover);
        $wp_query->set('ep_display_homepage', $display_homepage);
        $wp_query->set('ep_display_featured', $display_featured);
        $wp_query->set('ep_pin_position', $pin_position);
    endif;
}
?>